# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'User.updated_time'
        db.alter_column('facebook_users_user', 'updated_time', self.gf('django.db.models.fields.DateTimeField')(null=True))
    def backwards(self, orm):

        # Changing field 'User.updated_time'
        db.alter_column('facebook_users_user', 'updated_time', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(2012, 10, 21, 0, 0)))
    models = {
        'facebook_users.user': {
            'Meta': {'ordering': "['name']", 'object_name': 'User'},
            'bio': ('django.db.models.fields.TextField', [], {}),
            'birthday': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'cover': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'currency': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'devices': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'education': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'email': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'favorite_athletes': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'favorite_teams': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'gender': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'graph_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100'}),
            'hometown': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'installed': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'interested_in': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'languages': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'link': ('django.db.models.fields.URLField', [], {'max_length': '300'}),
            'locale': ('django.db.models.fields.CharField', [], {'max_length': '5'}),
            'location': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'middle_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'payment_pricepoints': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'picture': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'political': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'quotes': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'relationship_status': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'religion': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'security_settings': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'significant_other': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'third_party_id': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'timezone': ('django.db.models.fields.IntegerField', [], {'null': 'True'}),
            'updated_time': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'verified': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'video_upload_limits': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '100'}),
            'work': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'})
        }
    }

    complete_apps = ['facebook_users']


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'User'
        db.create_table('facebook_users_user', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('graph_id', self.gf('django.db.models.fields.CharField')(unique=True, max_length=100)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
        ))
        db.send_create_signal('facebook_users', ['User'])

    def backwards(self, orm):
        # Deleting model 'User'
        db.delete_table('facebook_users_user')

    models = {
        'facebook_users.user': {
            'Meta': {'ordering': "['name']", 'object_name': 'User'},
            'graph_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        }
    }

    complete_apps = ['facebook_users']


'''
Copyright 2011-2015 ramusus
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''

'''
QuickDjangoTest module for testing in Travis CI https://travis-ci.org
Change log:
 * 2014-10-24 updated for compatibility with Django 1.7
 * 2014-11-03 different databases support: sqlite3, mysql, postgres
 * 2014-12-31 pep8, python 3 compatibility
 * 2015-10-06 apache 2 license
'''

import argparse
import os
import sys

from django.conf import settings


class QuickDjangoTest(object):

    """
    A quick way to run the Django test suite without a fully-configured project.

    Example usage:

        >>> QuickDjangoTest('app1', 'app2')

    Based on a script published by Lukasz Dziedzia at:
    http://stackoverflow.com/questions/3841725/how-to-launch-tests-for-django-reusable-app
    """
    DIRNAME = os.path.dirname(__file__)
    INSTALLED_APPS = (
        'django.contrib.auth',
        'django.contrib.contenttypes',
        'django.contrib.sessions',
        'django.contrib.admin',
    )

    def __init__(self, *args, **kwargs):
        self.apps = args

        # Get the version of the test suite
        self.version = self.get_test_version()

        # Call the appropriate one
        if self.version == '1.7':
            self._tests_1_7()
        elif self.version == '1.2':
            self._tests_1_2()
        else:
            self._tests_old()

    def get_test_version(self):
        """
        Figure out which version of Django's test suite we have to play with.
        """
        from django import VERSION
        if VERSION[0] == 1 and VERSION[1] >= 7:
            return '1.7'
        elif VERSION[0] == 1 and VERSION[1] >= 2:
            return '1.2'
        else:
            return

    def get_database(self):
        test_db = os.environ.get('DB', 'sqlite')
        if test_db == 'mysql':
            database = {
                'ENGINE': 'django.db.backends.mysql',
                'NAME': 'django',
                'USER': 'root',
            }
        elif test_db == 'postgres':
            database = {
                'ENGINE': 'django.db.backends.postgresql_psycopg2',
                'USER': 'postgres',
                'NAME': 'django',
                'OPTIONS': {
                    'autocommit': True,
                }
            }
        else:
            database = {
                'ENGINE': 'django.db.backends.sqlite3',
                'NAME': os.path.join(self.DIRNAME, 'database.db'),
                'USER': '',
                'PASSWORD': '',
                'HOST': '',
                'PORT': '',
            }
        return {'default': database}

    def get_custom_settings(self):
        try:
            import settings_test
            settings_test = dict([(k, v) for k, v in settings_test.__dict__.items() if k[0] != '_'])
            INSTALLED_APPS = settings_test.pop('INSTALLED_APPS', [])
        except ImportError:
            settings_test = {}
            INSTALLED_APPS = []

        return INSTALLED_APPS, settings_test

    def _tests_old(self):
        """
        Fire up the Django test suite from before version 1.2
        """
        INSTALLED_APPS, settings_test = self.get_custom_settings()

        settings.configure(DEBUG=True,
                           DATABASE_ENGINE='sqlite3',
                           DATABASE_NAME=os.path.join(self.DIRNAME, 'database.db'),
                           INSTALLED_APPS=self.INSTALLED_APPS + INSTALLED_APPS + self.apps,
                           **settings_test
                           )
        from django.test.simple import run_tests
        failures = run_tests(self.apps, verbosity=1)
        if failures:
            sys.exit(failures)

    def _tests_1_2(self):
        """
        Fire up the Django test suite developed for version 1.2 and up
        """
        INSTALLED_APPS, settings_test = self.get_custom_settings()

        settings.configure(
            DEBUG=True,
            DATABASES=self.get_database(),
            INSTALLED_APPS=self.INSTALLED_APPS + INSTALLED_APPS + self.apps,
            **settings_test
        )

        from django.test.simple import DjangoTestSuiteRunner
        failures = DjangoTestSuiteRunner().run_tests(self.apps, verbosity=1)
        if failures:
            sys.exit(failures)

    def _tests_1_7(self):
        """
        Fire up the Django test suite developed for version 1.7 and up
        """
        INSTALLED_APPS, settings_test = self.get_custom_settings()

        settings.configure(
            DEBUG=True,
            DATABASES=self.get_database(),
            MIDDLEWARE_CLASSES=('django.middleware.common.CommonMiddleware',
                                'django.middleware.csrf.CsrfViewMiddleware'),
            INSTALLED_APPS = self.INSTALLED_APPS + INSTALLED_APPS + self.apps,
            **settings_test
        )

        from django.test.simple import DjangoTestSuiteRunner
        import django
        django.setup()
        failures = DjangoTestSuiteRunner().run_tests(self.apps, verbosity=1)
        if failures:
            sys.exit(failures)


if __name__ == '__main__':
    """
    What do when the user hits this file from the shell.

    Example usage:

        $ python quicktest.py app1 app2

    """
    parser = argparse.ArgumentParser(
        usage="[args]",
        description="Run Django tests on the provided applications."
    )
    parser.add_argument('apps', nargs='+', type=str)
    args = parser.parse_args()
    QuickDjangoTest(*args.apps)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'User.first_name'
        db.add_column('facebook_users_user', 'first_name',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.last_name'
        db.add_column('facebook_users_user', 'last_name',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.middle_name'
        db.add_column('facebook_users_user', 'middle_name',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.gender'
        db.add_column('facebook_users_user', 'gender',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=10),
                      keep_default=False)

        # Adding field 'User.locale'
        db.add_column('facebook_users_user', 'locale',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=5),
                      keep_default=False)

        # Adding field 'User.link'
        db.add_column('facebook_users_user', 'link',
                      self.gf('django.db.models.fields.URLField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.cover'
        db.add_column('facebook_users_user', 'cover',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.username'
        db.add_column('facebook_users_user', 'username',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.third_party_id'
        db.add_column('facebook_users_user', 'third_party_id',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.updated_time'
        db.add_column('facebook_users_user', 'updated_time',
                      self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(1970, 1, 1, 0, 0)),
                      keep_default=False)

        # Adding field 'User.email'
        db.add_column('facebook_users_user', 'email',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.timezone'
        db.add_column('facebook_users_user', 'timezone',
                      self.gf('django.db.models.fields.IntegerField')(null=True),
                      keep_default=False)

        # Adding field 'User.bio'
        db.add_column('facebook_users_user', 'bio',
                      self.gf('django.db.models.fields.TextField')(default=''),
                      keep_default=False)

        # Adding field 'User.birthday'
        db.add_column('facebook_users_user', 'birthday',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=300),
                      keep_default=False)

        # Adding field 'User.languages'
        db.add_column('facebook_users_user', 'languages',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.installed'
        db.add_column('facebook_users_user', 'installed',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.verified'
        db.add_column('facebook_users_user', 'verified',
                      self.gf('django.db.models.fields.BooleanField')(default=False),
                      keep_default=False)

        # Adding field 'User.currency'
        db.add_column('facebook_users_user', 'currency',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.devices'
        db.add_column('facebook_users_user', 'devices',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.education'
        db.add_column('facebook_users_user', 'education',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.hometown'
        db.add_column('facebook_users_user', 'hometown',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.interested_in'
        db.add_column('facebook_users_user', 'interested_in',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.location'
        db.add_column('facebook_users_user', 'location',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.payment_pricepoints'
        db.add_column('facebook_users_user', 'payment_pricepoints',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.favorite_athletes'
        db.add_column('facebook_users_user', 'favorite_athletes',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.favorite_teams'
        db.add_column('facebook_users_user', 'favorite_teams',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.political'
        db.add_column('facebook_users_user', 'political',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.picture'
        db.add_column('facebook_users_user', 'picture',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.quotes'
        db.add_column('facebook_users_user', 'quotes',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.relationship_status'
        db.add_column('facebook_users_user', 'relationship_status',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.religion'
        db.add_column('facebook_users_user', 'religion',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.security_settings'
        db.add_column('facebook_users_user', 'security_settings',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.significant_other'
        db.add_column('facebook_users_user', 'significant_other',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.video_upload_limits'
        db.add_column('facebook_users_user', 'video_upload_limits',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

        # Adding field 'User.website'
        db.add_column('facebook_users_user', 'website',
                      self.gf('django.db.models.fields.URLField')(default='', max_length=100),
                      keep_default=False)

        # Adding field 'User.work'
        db.add_column('facebook_users_user', 'work',
                      self.gf('annoying.fields.JSONField')(max_length=500, null=True),
                      keep_default=False)

    def backwards(self, orm):
        # Deleting field 'User.first_name'
        db.delete_column('facebook_users_user', 'first_name')

        # Deleting field 'User.last_name'
        db.delete_column('facebook_users_user', 'last_name')

        # Deleting field 'User.middle_name'
        db.delete_column('facebook_users_user', 'middle_name')

        # Deleting field 'User.gender'
        db.delete_column('facebook_users_user', 'gender')

        # Deleting field 'User.locale'
        db.delete_column('facebook_users_user', 'locale')

        # Deleting field 'User.link'
        db.delete_column('facebook_users_user', 'link')

        # Deleting field 'User.cover'
        db.delete_column('facebook_users_user', 'cover')

        # Deleting field 'User.username'
        db.delete_column('facebook_users_user', 'username')

        # Deleting field 'User.third_party_id'
        db.delete_column('facebook_users_user', 'third_party_id')

        # Deleting field 'User.updated_time'
        db.delete_column('facebook_users_user', 'updated_time')

        # Deleting field 'User.email'
        db.delete_column('facebook_users_user', 'email')

        # Deleting field 'User.timezone'
        db.delete_column('facebook_users_user', 'timezone')

        # Deleting field 'User.bio'
        db.delete_column('facebook_users_user', 'bio')

        # Deleting field 'User.birthday'
        db.delete_column('facebook_users_user', 'birthday')

        # Deleting field 'User.languages'
        db.delete_column('facebook_users_user', 'languages')

        # Deleting field 'User.installed'
        db.delete_column('facebook_users_user', 'installed')

        # Deleting field 'User.verified'
        db.delete_column('facebook_users_user', 'verified')

        # Deleting field 'User.currency'
        db.delete_column('facebook_users_user', 'currency')

        # Deleting field 'User.devices'
        db.delete_column('facebook_users_user', 'devices')

        # Deleting field 'User.education'
        db.delete_column('facebook_users_user', 'education')

        # Deleting field 'User.hometown'
        db.delete_column('facebook_users_user', 'hometown')

        # Deleting field 'User.interested_in'
        db.delete_column('facebook_users_user', 'interested_in')

        # Deleting field 'User.location'
        db.delete_column('facebook_users_user', 'location')

        # Deleting field 'User.payment_pricepoints'
        db.delete_column('facebook_users_user', 'payment_pricepoints')

        # Deleting field 'User.favorite_athletes'
        db.delete_column('facebook_users_user', 'favorite_athletes')

        # Deleting field 'User.favorite_teams'
        db.delete_column('facebook_users_user', 'favorite_teams')

        # Deleting field 'User.political'
        db.delete_column('facebook_users_user', 'political')

        # Deleting field 'User.picture'
        db.delete_column('facebook_users_user', 'picture')

        # Deleting field 'User.quotes'
        db.delete_column('facebook_users_user', 'quotes')

        # Deleting field 'User.relationship_status'
        db.delete_column('facebook_users_user', 'relationship_status')

        # Deleting field 'User.religion'
        db.delete_column('facebook_users_user', 'religion')

        # Deleting field 'User.security_settings'
        db.delete_column('facebook_users_user', 'security_settings')

        # Deleting field 'User.significant_other'
        db.delete_column('facebook_users_user', 'significant_other')

        # Deleting field 'User.video_upload_limits'
        db.delete_column('facebook_users_user', 'video_upload_limits')

        # Deleting field 'User.website'
        db.delete_column('facebook_users_user', 'website')

        # Deleting field 'User.work'
        db.delete_column('facebook_users_user', 'work')

    models = {
        'facebook_users.user': {
            'Meta': {'ordering': "['name']", 'object_name': 'User'},
            'bio': ('django.db.models.fields.TextField', [], {}),
            'birthday': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'cover': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'currency': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'devices': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'education': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'email': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'favorite_athletes': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'favorite_teams': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'gender': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'graph_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100'}),
            'hometown': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'installed': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'interested_in': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'languages': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'link': ('django.db.models.fields.URLField', [], {'max_length': '300'}),
            'locale': ('django.db.models.fields.CharField', [], {'max_length': '5'}),
            'location': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'middle_name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'payment_pricepoints': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'picture': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'political': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'quotes': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'relationship_status': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'religion': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'security_settings': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'significant_other': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'third_party_id': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'timezone': ('django.db.models.fields.IntegerField', [], {'null': 'True'}),
            'updated_time': ('django.db.models.fields.DateTimeField', [], {}),
            'username': ('django.db.models.fields.CharField', [], {'max_length': '300'}),
            'verified': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'video_upload_limits': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '100'}),
            'work': ('annoying.fields.JSONField', [], {'max_length': '500', 'null': 'True'})
        }
    }

    complete_apps = ['facebook_users']


# -*- coding: utf-8 -*-
'''
Copyright 2011-2015 ramusus
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''
from django.db import models
from facebook_api.models import FacebookGraphIDModel, FacebookGraphManager
from facebook_api import fields
import logging

log = logging.getLogger('facebook_users')

class FacebookUserGraphManager(FacebookGraphManager):

    def fetch(self, *args, **kwargs):
        if 'fields' not in kwargs:
            kwargs['fields'] = 'bio,address,email,gender,id,languages,link,installed,first_name,cover,about,education,currency,devices,birthday,religion,favorite_athletes,favorite_teams,hometown,inspirational_people,interested_in,sports,quotes,meeting_for,username,middle_name,work,website,last_name,video_upload_limits,is_verified,name,locale,location,payment_pricepoints,political,security_settings,relationship_status,significant_other,third_party_id,timezone,updated_time,age_range'
        return super(FacebookUserGraphManager, self).fetch(*args, **kwargs)

class User(FacebookGraphIDModel):
    class Meta:
        verbose_name = 'Facebook user'
        verbose_name_plural = 'Facebook users'

    name = models.CharField(max_length=300, help_text='The user\'s full name')

    first_name = models.CharField(max_length=300, help_text='The user\'s first name')
    last_name = models.CharField(max_length=300, help_text='The user\'s last name')
    middle_name = models.CharField(max_length=300, help_text='The user\'s middle name')

    gender = models.CharField(max_length=10, help_text='The user\'s gender: female or male')
    locale = models.CharField(max_length=5, help_text='The user\'s locale')
    link = models.URLField(max_length=300, help_text='The URL of the profile for the user on Facebook')
    cover = fields.JSONField(max_length=500, null=True, help_text='The user\'s cover photo (must be explicitly requested using fields=cover parameter)')

    username = models.CharField(max_length=300, help_text='The user\'s Facebook username')
    third_party_id = models.CharField(max_length=300, help_text='An anonymous, but unique identifier for the user')
    updated_time = models.DateTimeField(null=True, help_text='The last time the user\'s profile was updated; changes to the languages, link, timezone, verified, interested_in, favorite_athletes, favorite_teams, and video_upload_limits are not not reflected in this value')

    # fields from https://developers.facebook.com/docs/reference/api/user/
    email = models.CharField(max_length=100, help_text='The proxied or contact email address granted by the user')
    timezone = models.IntegerField(null=True, help_text='The user\'s timezone offset from UTC')
    bio = models.TextField(help_text='The user\'s biography')
    birthday = models.CharField(max_length=300, help_text='The user\'s birthday')

    languages = fields.JSONField(max_length=500, null=True, help_text='The user\'s languages')
    installed = fields.JSONField(max_length=500, null=True, help_text='Specifies whether the user has installed the application associated with the app access token that is used to make the request; only returned if specifically requested via the fields URL parameter')

    # TODO: rename to is_verified according to https://developers.facebook.com/tools/explorer/291716840848442/?method=GET&path=100000007637389%3Ffields%3Dcover%2Ccurrency%2Cemail%2Cabout%2Cage_range%2Cbirthday%2Cgender%2Chometown%2Cid%2Cdevices%2Cfirst_name%2Clast_name%2Caddress%2Cinstall_type%2Cinstalled%2Cinterested_in%2Clanguages%2Clink%2Clocation%2Cmeeting_for%2Cbio%2Ceducation%2Cmiddle_name%2Cname_format%2Cname%2Cinspirational_people%2Cpolitical%2Cquotes%2Crelationship_status%2Creligion%2Csecurity_settings%2Csignificant_other%2Csports%2Cwork%2Cwebsite%2Ctimezone%2Ctelevision%2Ctagged%2Cupdated_time%2Cvideo_upload_limits%2Cphotos%2Cpicture%2Cposts%2Calbums%2Cgames%2Cverified%2Cvideos%2Cbooks%2Cmusic%2Cis_verified&
    verified = models.BooleanField(help_text='The user\'s account verification status, either true or false (see below)')

    currency = fields.JSONField(max_length=500, null=True, help_text='The user\'s currency settings (must be explicitly requested using a fields=currency URL parameter)')
    devices = fields.JSONField(max_length=500, null=True, help_text='A list of the user\'s devices beyond desktop')
    education = fields.JSONField(max_length=500, null=True, help_text='A list of the user\'s education history')

    hometown = fields.JSONField(max_length=500, null=True, help_text='The user\'s hometown')
    interested_in = fields.JSONField(max_length=500, null=True, help_text='The genders the user is interested in')
    location = fields.JSONField(max_length=500, null=True, help_text='The user\'s current city')
    payment_pricepoints = fields.JSONField(max_length=500, null=True, help_text='The payment price-points available for that user')
    favorite_athletes = fields.JSONField(max_length=500, null=True, help_text='The user\'s favorite athletes; this field is deprecated and will be removed in the near future')
    favorite_teams = fields.JSONField(max_length=500, null=True, help_text='The user\'s favorite teams; this field is deprecated and will be removed in the near future')

    political = models.CharField(max_length=100, help_text='The user\'s political view')
    picture = models.CharField(max_length=100, help_text='The URL of the user\'s profile pic (only returned if you explicitly specify a \'fields=picture\' param)')
    quotes = models.CharField(max_length=100, help_text='The user\'s favorite quotes')
    relationship_status = models.CharField(max_length=100, help_text='The user\'s relationship status: Single, In a relationship, Engaged, Married, It\'s complicated, In an open relationship, Widowed, Separated, Divorced, In a civil union, In a domestic partnership')
    religion = models.CharField(max_length=100, help_text='The user\'s religion')

    security_settings = fields.JSONField(max_length=500, null=True, help_text='Information about security settings enabled on the user\'s account (must be explicitly requested using a fields=security_settings URL parameter)')
    significant_other = fields.JSONField(max_length=500, null=True, help_text='The user\'s significant other')
    video_upload_limits = fields.JSONField(max_length=500, null=True, help_text='The size of the video file and the length of the video that a user can upload; only returned if specifically requested via the fields URL parameter')

    website = models.URLField(max_length=100, help_text='The URL of the user\'s personal website')
    work = fields.JSONField(max_length=500, null=True, help_text='A list of the user\'s work history')

    objects = models.Manager()
    remote = FacebookUserGraphManager()

    def __unicode__(self):
        return self.name

    def picture_url(self, w, h):
        return 'https://graph.facebook.com/%s/picture?width=%d&height=%d' % (self.graph_id, w, h)

    def set_name(self, name):
        name_parts = name.split()
        self.first_name = name_parts[0]
        if len(name_parts) == 2:
            self.last_name = name_parts[1]
        elif len(name_parts) > 2:
            self.middle_name = name_parts[1]
            self.last_name = ' '.join(name_parts[2:])



# -*- coding: utf-8 -*-
'''
Copyright 2011-2015 ramusus
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''
from django.conf import settings
from django.contrib import admin
from django.contrib.contenttypes import generic

from facebook_api.admin import FacebookModelAdmin

from .models import User


class UserAdmin(FacebookModelAdmin):
    list_display = ('name','first_name','last_name','gender')
    list_display_links = ('name',)
    list_filter = ('gender',)
    search_fields = ('name',)

#    def get_readonly_fields(self, *args, **kwargs):
#        fields = super(UserAdmin, self).get_readonly_fields(*args, **kwargs)
#        return fields + ['likes']


if 'facebook_posts' in settings.INSTALLED_APPS:
    from facebook_posts.models import PostOwner, Comment

    class PostInline(generic.GenericTabularInline):
        model = PostOwner
        ct_field = 'owner_content_type'
        ct_fk_field = 'owner_id'
        fields = ('post',)
        readonly_fields = fields
        extra = False
        can_delete = False

    class CommentInline(generic.GenericTabularInline):
        model = Comment
        ct_field = 'author_content_type'
        ct_fk_field = 'author_id'
        fields = ('message','likes_count')
        readonly_fields = fields
        extra = False
        can_delete = False

    UserAdmin.inlines = [PostInline, CommentInline]

admin.site.register(User, UserAdmin)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'User.name'
        db.alter_column('facebook_users_user', 'name', self.gf('django.db.models.fields.CharField')(max_length=300))
    def backwards(self, orm):

        # Changing field 'User.name'
        db.alter_column('facebook_users_user', 'name', self.gf('django.db.models.fields.CharField')(max_length=200))
    models = {
        'facebook_users.user': {
            'Meta': {'ordering': "['name']", 'object_name': 'User'},
            'graph_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '300'})
        }
    }

    complete_apps = ['facebook_users']